@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,7 +15,10 @@
 
 
 # 无效的资源ID，用于资源不存在或已过期。
-INVALIDPARAMETER_DBAUDITRESOURCEIDINVAILD = 'InvalidParameter.DbauditResourceIdInvaild'
+INVALIDPARAMETER_RESOURCEID = 'InvalidParameter.ResourceId'
+
+# 审计资源ID 错误。
+INVALIDPARAMETER_RESOURCEIDERROR = 'InvalidParameter.ResourceIdError'
 
 # 无操作权限。
 UNAUTHORIZEDOPERATION_NOPERMISSION = 'UnauthorizedOperation.NoPermission'
