@@ -53,6 +53,9 @@ INTERNALERROR_GETACCOUNTSTATUSFAILED = 'InternalError.GetAccountStatusFailed'
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
+# 快照策略未找到。
+INVALIDPARAMETER_AUTOPOLICYNOTFOUND = 'InvalidParameter.AutoPolicyNotFound'
+
 # 用于保证请求幂等性的字符串长度超过限制（不能超过64字节）。
 INVALIDPARAMETERVALUE_CLIENTTOKENLIMITEXCEEDED = 'InvalidParameterValue.ClientTokenLimitExceeded'
 
@@ -119,6 +122,9 @@ INVALIDPARAMETERVALUE_INVALIDRESOURCETAGS = 'InvalidParameterValue.InvalidResour
 # 读写权限设置错误。
 INVALIDPARAMETERVALUE_INVALIDRWPERMISSION = 'InvalidParameterValue.InvalidRwPermission'
 
+# 无效的快照状态。
+INVALIDPARAMETERVALUE_INVALIDSNAPSHOTSTATUS = 'InvalidParameterValue.InvalidSnapshotStatus'
+
 # 资源包不存在或已绑定。
 INVALIDPARAMETERVALUE_INVALIDSTORAGERESOURCEPKG = 'InvalidParameterValue.InvalidStorageResourcePkg'
 
@@ -131,6 +137,12 @@ INVALIDPARAMETERVALUE_INVALIDSUBNETID = 'InvalidParameterValue.InvalidSubnetId'
 # 标签键不能为空。
 INVALIDPARAMETERVALUE_INVALIDTAGKEY = 'InvalidParameterValue.InvalidTagKey'
 
+# 标签值为空或字符无效。
+INVALIDPARAMETERVALUE_INVALIDTAGVALUE = 'InvalidParameterValue.InvalidTagValue'
+
+# 无效的容量值。
+INVALIDPARAMETERVALUE_INVALIDTURBOCAPACITY = 'InvalidParameterValue.InvalidTurboCapacity'
+
 # 用户权限设置错误。
 INVALIDPARAMETERVALUE_INVALIDUSERPERMISSION = 'InvalidParameterValue.InvalidUserPermission'
 
@@ -230,6 +242,9 @@ RESOURCEINSUFFICIENT_SUBNETIPALLOCCUPIED = 'ResourceInsufficient.SubnetIpAllOccu
 # 该资源的标签个数达到最大限制。
 RESOURCEINSUFFICIENT_TAGLIMITEXCEEDED = 'ResourceInsufficient.TagLimitExceeded'
 
+# 标签限额不足。
+RESOURCEINSUFFICIENT_TAGQUOTASEXCEEDED = 'ResourceInsufficient.TagQuotasExceeded'
+
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
 
