@@ -161,83 +161,6 @@ class CreatePictureResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
-class CreateTroubleInfoRequest(AbstractModel):
-    """CreateTroubleInfo请求参数结构体
-
-    """
-
-    def __init__(self):
-        r"""
-        :param SdkAppId: 应用的ID
-        :type SdkAppId: str
-        :param RoomId: 房间ID
-        :type RoomId: str
-        :param TeacherUserId: 老师用户ID
-        :type TeacherUserId: str
-        :param StudentUserId: 学生用户ID
-        :type StudentUserId: str
-        :param TroubleUserId: 体验异常端（老师或学生）的用户 ID。
-        :type TroubleUserId: str
-        :param TroubleType: 异常类型。
-1. 仅视频异常
-2. 仅声音异常
-3. 音视频都异常
-5. 进房异常
-4. 切课
-6. 求助
-7. 问题反馈
-8. 投诉
-        :type TroubleType: int
-        :param TroubleTime: 异常发生的UNIX 时间戳，单位为秒。
-        :type TroubleTime: int
-        :param TroubleMsg: 异常详情
-        :type TroubleMsg: str
-        """
-        self.SdkAppId = None
-        self.RoomId = None
-        self.TeacherUserId = None
-        self.StudentUserId = None
-        self.TroubleUserId = None
-        self.TroubleType = None
-        self.TroubleTime = None
-        self.TroubleMsg = None
-
-
-    def _deserialize(self, params):
-        self.SdkAppId = params.get("SdkAppId")
-        self.RoomId = params.get("RoomId")
-        self.TeacherUserId = params.get("TeacherUserId")
-        self.StudentUserId = params.get("StudentUserId")
-        self.TroubleUserId = params.get("TroubleUserId")
-        self.TroubleType = params.get("TroubleType")
-        self.TroubleTime = params.get("TroubleTime")
-        self.TroubleMsg = params.get("TroubleMsg")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
-        
-
-
-class CreateTroubleInfoResponse(AbstractModel):
-    """CreateTroubleInfo返回参数结构体
-
-    """
-
-    def __init__(self):
-        r"""
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
-        self.RequestId = None
-
-
-    def _deserialize(self, params):
-        self.RequestId = params.get("RequestId")
-
-
 class DeletePictureRequest(AbstractModel):
     """DeletePicture请求参数结构体
 
@@ -290,11 +213,12 @@ class DescribeAbnormalEventRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param SdkAppId: 用户SDKAppID，查询SDKAppID下任意20条异常体验事件（可能不同房间）
+        :param SdkAppId: 用户SdkAppId（如：1400xxxxxx）
         :type SdkAppId: str
-        :param StartTime: 查询开始时间,本地unix时间戳（1592448600s）
+        :param StartTime: 查询开始时间，本地unix时间戳，单位为秒（如：1590065777）
+注意：支持查询14天内的数据
         :type StartTime: int
-        :param EndTime: 查询结束时间,本地unix时间戳（1592449080s）
+        :param EndTime: 查询结束时间，本地unix时间戳，单位为秒（如：1590065877）注意：与StartTime间隔时间不超过1小时。
         :type EndTime: int
         :param RoomId: 房间号，查询房间内任意20条以内异常体验事件
         :type RoomId: str
@@ -356,15 +280,17 @@ class DescribeCallDetailRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param CommId: 通话 ID（唯一标识一次通话）： sdkappid_roomgString（房间号_createTime（房间创建时间，unix时间戳，单位为s）例：1400353843_218695_1590065777。通过 DescribeRoomInformation（查询房间列表）接口获取（链接：https://cloud.tencent.com/document/product/647/44050）
+        :param CommId: 通话 ID（唯一标识一次通话）： SdkAppId_RoomId（房间号）_ CreateTime（房间创建时间，unix时间戳，单位为s）例：1400xxxxxx_218695_1590065777。通过 DescribeRoomInfo（查询历史房间列表）接口获取（[查询历史房间列表](https://cloud.tencent.com/document/product/647/44050)）。
         :type CommId: str
-        :param StartTime: 查询开始时间，14天内。本地unix时间戳（1590065777s），查询实时数据时，查询起止时间不超过1个小时。
+        :param StartTime: 查询开始时间，本地unix时间戳，单位为秒（如：1590065777），
+注意：支持查询14天内的数据。
         :type StartTime: int
-        :param EndTime: 查询结束时间，本地unix时间戳（1590065877s）
+        :param EndTime: 查询结束时间，本地unix时间戳，单位为秒（如：1590065877）
+注意：DataType 不为null ，与StartTime间隔时间不超过1小时；DataType 为null，与StartTime间隔时间不超过4小时。
         :type EndTime: int
-        :param SdkAppId: 用户SDKAppID（1400353843）
+        :param SdkAppId: 用户SdkAppId（如：1400xxxxxx）。
         :type SdkAppId: str
-        :param UserIds: 需查询的用户数组，不填默认返回6个用户,最多可填6个用户
+        :param UserIds: 需查询的用户数组，默认不填返回6个用户。
         :type UserIds: list of str
         :param DataType: 需查询的指标，不填则只返回用户列表，填all则返回所有指标。
 appCpu：APP CPU使用率；
@@ -381,9 +307,13 @@ bigvLoss：上/下行视频丢包率；
 bigvWidth：上/下行分辨率宽；
 bigvHeight：上/下行分辨率高
         :type DataType: list of str
-        :param PageNumber: 设置分页index，从0开始（PageNumber和PageSize 其中一个不填均默认返回6条数据）
+        :param PageNumber: 当前页数，默认为0，
+注意：PageNumber和PageSize 其中一个不填均默认返回6条数据。
         :type PageNumber: str
-        :param PageSize: 设置分页大小（PageNumber和PageSize 其中一个不填均默认返回6条数据,DataType，UserIds不为null，PageSize最大不超过6，DataType，UserIds为null，PageSize最大不超过100）
+        :param PageSize: 每页个数，默认为6，
+范围：[1，100]
+注意：DataType不为null，UserIds长度不能超过6，PageSize最大值不超过6；
+DataType 为null，UserIds长度不超过100，PageSize最大不超过100。
         :type PageSize: str
         """
         self.CommId = None
@@ -462,15 +392,17 @@ class DescribeDetailEventRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param CommId: 通话 ID（唯一标识一次通话）： sdkappid_roomgString（房间号_createTime（房间创建时间，unix时间戳，单位s）。通过 DescribeRoomInformation（查询房间列表）接口获取。（链接：https://cloud.tencent.com/document/product/647/44050）
+        :param CommId: 通话 ID（唯一标识一次通话）： SdkAppId_RoomId（房间号）_ CreateTime（房间创建时间，unix时间戳，单位为s）例：1400xxxxxx_218695_1590065777。通过 DescribeRoomInfo（查询历史房间列表）接口获取（[查询历史房间列表](https://cloud.tencent.com/document/product/647/44050)）。
         :type CommId: str
-        :param StartTime: 查询开始时间，14天内。本地unix时间戳（1588055615s）
+        :param StartTime: 查询开始时间，本地unix时间戳，单位为秒（如：1590065777）
+注意：支持查询14天内的数据
         :type StartTime: int
-        :param EndTime: 查询结束时间，本地unix时间戳（1588058615s）
+        :param EndTime: 查询结束时间，本地unix时间戳，单位为秒（如：1590065877）
+注意：查询时间大于房间结束时间，以房间结束时间为准。
         :type EndTime: int
-        :param UserId: 用户id
+        :param UserId: 用户UserId
         :type UserId: str
-        :param RoomId: 房间号
+        :param RoomId: 房间号（如：223）
         :type RoomId: str
         """
         self.CommId = None
@@ -521,6 +453,72 @@ class DescribeDetailEventResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeExternalTrtcMeasureRequest(AbstractModel):
+    """DescribeExternalTrtcMeasure请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param StartTime: 查询开始日期。
+        :type StartTime: str
+        :param EndTime: 查询结束日期。
+        :type EndTime: str
+        :param SdkAppId: 对应的应用。如果没有这个参数，表示获取用户名下全部实时音视频应用的汇总。
+        :type SdkAppId: int
+        """
+        self.StartTime = None
+        self.EndTime = None
+        self.SdkAppId = None
+
+
+    def _deserialize(self, params):
+        self.StartTime = params.get("StartTime")
+        self.EndTime = params.get("EndTime")
+        self.SdkAppId = params.get("SdkAppId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeExternalTrtcMeasureResponse(AbstractModel):
+    """DescribeExternalTrtcMeasure返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param SdkAppIdTrtrTimeUsages: 每个SdkAppId的时长使用信息
+        :type SdkAppIdTrtrTimeUsages: list of SdkAppIdNewTrtcTimeUsage
+        :param AnchorUsageMode: 主播的用量统计方式。取值"InRoomTime":房间时长,"SubscribeTime":"订阅时长","Bandwidth":带宽
+        :type AnchorUsageMode: str
+        :param AudienceUsageMode: 观众的用量统计方式。取值"InRoomTime":在房间时长,"SubscribeTime":"订阅时长","Bandwidth":带宽,"MergeWithAnchor":"不区分麦上麦下"
+        :type AudienceUsageMode: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.SdkAppIdTrtrTimeUsages = None
+        self.AnchorUsageMode = None
+        self.AudienceUsageMode = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("SdkAppIdTrtrTimeUsages") is not None:
+            self.SdkAppIdTrtrTimeUsages = []
+            for item in params.get("SdkAppIdTrtrTimeUsages"):
+                obj = SdkAppIdNewTrtcTimeUsage()
+                obj._deserialize(item)
+                self.SdkAppIdTrtrTimeUsages.append(obj)
+        self.AnchorUsageMode = params.get("AnchorUsageMode")
+        self.AudienceUsageMode = params.get("AudienceUsageMode")
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeHistoryScaleRequest(AbstractModel):
     """DescribeHistoryScale请求参数结构体
 
@@ -528,11 +526,13 @@ class DescribeHistoryScaleRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param SdkAppId: 用户sdkappid(1400188366)
+        :param SdkAppId: 用户SdkAppId（如：1400xxxxxx）
         :type SdkAppId: str
-        :param StartTime: 查询开始时间，5天内。本地unix时间戳（1587571000s）
+        :param StartTime: 查询开始时间，本地unix时间戳，单位为秒（如：1590065777）
+注意：支持查询14天内的数据。
         :type StartTime: int
-        :param EndTime: 查询结束时间，本地unix时间戳（1588034999s）
+        :param EndTime: 查询结束时间，本地unix时间戳，单位为秒（如：1590065877），建议与StartTime间隔时间超过24小时。
+注意：按天统计，结束时间小于前一天，否则查询数据为空（如：需查询20号数据，结束时间需小于20号0点）。
         :type EndTime: int
         """
         self.SdkAppId = None
@@ -716,17 +716,21 @@ class DescribeRoomInformationRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param SdkAppId: 用户sdkappid
+        :param SdkAppId: 用户SdkAppId（如：1400xxxxxx）
         :type SdkAppId: str
-        :param StartTime: 查询开始时间，14天内。本地unix时间戳（1588031999）
+        :param StartTime: 查询开始时间，本地unix时间戳，单位为秒（如：1590065777）
+注意：支持查询14天内的数据
         :type StartTime: int
-        :param EndTime: 查询结束时间，本地unix时间戳（1588034999）
+        :param EndTime: 查询结束时间，本地unix时间戳，单位为秒（如：1590065877）
+注意：与StartTime间隔时间不超过24小时。
         :type EndTime: int
-        :param RoomId: 字符串房间号
+        :param RoomId: 房间号（如：223)
         :type RoomId: str
-        :param PageNumber: 分页index，从0开始（PageNumber和PageSize 其中一个不填均默认返回10条数据）
+        :param PageNumber: 当前页数，默认为0，
+注意：PageNumber和PageSize 其中一个不填均默认返回10条数据。
         :type PageNumber: str
-        :param PageSize: 分页大小（PageNumber和PageSize 其中一个不填均默认返回10条数据,最大不超过100）
+        :param PageSize: 每页个数，默认为10，
+范围：[1，100]
         :type PageSize: str
         """
         self.SdkAppId = None
@@ -849,19 +853,24 @@ class DescribeUserInformationRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param CommId: 通话 ID（唯一标识一次通话）： sdkappid_roomgString（房间号_createTime（房间创建时间，unix时间戳，单位为s）例：1400353843_218695_1590065777。通过 DescribeRoomInformation（查询房间列表）接口获取（链接：https://cloud.tencent.com/document/product/647/44050）
+        :param CommId: 通话 ID（唯一标识一次通话）： SdkAppId_RoomId（房间号）_ CreateTime（房间创建时间，unix时间戳，单位为s）例：1400xxxxxx_218695_1590065777。通过 DescribeRoomInfo（查询历史房间列表）接口获取（[查询历史房间列表](https://cloud.tencent.com/document/product/647/44050)）。
         :type CommId: str
-        :param StartTime: 查询开始时间，14天内。本地unix时间戳（1590065777）
+        :param StartTime: 查询开始时间，本地unix时间戳，单位为秒（如：1590065777）
+注意：支持查询14天内的数据
         :type StartTime: int
-        :param EndTime: 查询结束时间，本地unix时间戳（1590065877）
+        :param EndTime: 查询结束时间，本地unix时间戳，单位为秒（如：1590065877）
+注意：与StartTime间隔时间不超过4小时。
         :type EndTime: int
-        :param SdkAppId: 用户SDKAppID（1400353843）
+        :param SdkAppId: 用户SdkAppId（如：1400xxxxxx）
         :type SdkAppId: str
-        :param UserIds: 需查询的用户数组，不填默认返回6个用户,最多可填6个用户
+        :param UserIds: 需查询的用户数组，不填默认返回6个用户
+范围：[1，100]。
         :type UserIds: list of str
-        :param PageNumber: 设置分页index，从0开始（PageNumber和PageSize 其中一个不填均默认返回6条数据）
+        :param PageNumber: 当前页数，默认为0，
+注意：PageNumber和PageSize 其中一个不填均默认返回6条数据。
         :type PageNumber: str
-        :param PageSize: 设置分页大小（PageNumber和PageSize 其中一个不填均默认返回6条数据,PageSize最大不超过100）
+        :param PageSize: 每页个数，默认为6，
+范围：[1，100]。
         :type PageSize: str
         """
         self.CommId = None
@@ -1761,6 +1770,48 @@ class ScaleInfomation(AbstractModel):
         
 
 
+class SdkAppIdNewTrtcTimeUsage(AbstractModel):
+    """SdkAppId级别实时音视频的用量数据
+
+    """
+
+    def __init__(self):
+        r"""
+        :param SdkAppId: SdkAppId的值。
+        :type SdkAppId: str
+        :param TrtcTimeUsages: 统计的时间点数据。
+        :type TrtcTimeUsages: list of TrtcTimeNewUsage
+        :param AudienceTrtcTimeUsages: 统计的麦下用量的时间点数据。
+        :type AudienceTrtcTimeUsages: list of TrtcTimeNewUsage
+        """
+        self.SdkAppId = None
+        self.TrtcTimeUsages = None
+        self.AudienceTrtcTimeUsages = None
+
+
+    def _deserialize(self, params):
+        self.SdkAppId = params.get("SdkAppId")
+        if params.get("TrtcTimeUsages") is not None:
+            self.TrtcTimeUsages = []
+            for item in params.get("TrtcTimeUsages"):
+                obj = TrtcTimeNewUsage()
+                obj._deserialize(item)
+                self.TrtcTimeUsages.append(obj)
+        if params.get("AudienceTrtcTimeUsages") is not None:
+            self.AudienceTrtcTimeUsages = []
+            for item in params.get("AudienceTrtcTimeUsages"):
+                obj = TrtcTimeNewUsage()
+                obj._deserialize(item)
+                self.AudienceTrtcTimeUsages.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class SdkAppIdRecordUsage(AbstractModel):
     """SdkAppId级别录制时长数据。
 
@@ -2135,6 +2186,66 @@ class TimeValue(AbstractModel):
         
 
 
+class TrtcTimeNewUsage(AbstractModel):
+    """实时音视频用量的某一时间段的统计信息.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param TimeKey: 时间点。
+        :type TimeKey: str
+        :param VoiceUserNum: 通话人数。仅供参考。在线人数以仪表盘查询结果为准。
+        :type VoiceUserNum: int
+        :param VideoTime: 音视频通话时长。单位：秒。
+        :type VideoTime: int
+        :param Class1VideoTime: 标清视频通话时长。单位：秒。
+        :type Class1VideoTime: int
+        :param Class2VideoTime: 高清视频通话时长。单位：秒。
+        :type Class2VideoTime: int
+        :param Class3VideoTime: 超高清视频通话时长。单位：秒。
+        :type Class3VideoTime: int
+        :param AudioTime: 音频通话时长。单位：秒。
+        :type AudioTime: int
+        :param Bandwidth: 带宽。单位：Mbps。
+        :type Bandwidth: float
+        :param Video2KTime: 2k视频通话时长。单位：秒。
+        :type Video2KTime: int
+        :param Video4KTime: 4k视频通话时长。单位：秒。
+        :type Video4KTime: int
+        """
+        self.TimeKey = None
+        self.VoiceUserNum = None
+        self.VideoTime = None
+        self.Class1VideoTime = None
+        self.Class2VideoTime = None
+        self.Class3VideoTime = None
+        self.AudioTime = None
+        self.Bandwidth = None
+        self.Video2KTime = None
+        self.Video4KTime = None
+
+
+    def _deserialize(self, params):
+        self.TimeKey = params.get("TimeKey")
+        self.VoiceUserNum = params.get("VoiceUserNum")
+        self.VideoTime = params.get("VideoTime")
+        self.Class1VideoTime = params.get("Class1VideoTime")
+        self.Class2VideoTime = params.get("Class2VideoTime")
+        self.Class3VideoTime = params.get("Class3VideoTime")
+        self.AudioTime = params.get("AudioTime")
+        self.Bandwidth = params.get("Bandwidth")
+        self.Video2KTime = params.get("Video2KTime")
+        self.Video4KTime = params.get("Video4KTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class UserInformation(AbstractModel):
     """用户信息，包括用户进房时间，退房时间等
 
